
#
# read structure files, fit to first one and write out a .edm file
#
#
# IMPORTANT: this script requires a Xplor-NIH version newer than 2.9.1
#

from xplor import command
import re
import sys
import time
import os

import cdsList
import cdsVector
import vec3
import vmdInter
from pdbTool import PDBTool
from atomSelAction import Fit

sim = xplor.simulation

import protocol

#
# read psf file
#
protocol.initStruct("lap2.psf")

#
# names of the structure files are in structures.list
#
protocol.initCoords("cterm_ave.chr")

#coordinates to be fit to
targetCoords=sim.atomPosArr()


vmd= vmdInter.VMDInter()

atomPosList = []
def fitCmd():
    # fit each structure to reference structure
    fitter = Fit(targetCoords,
                 AtomSel("""(name ca or name c or name n) and
                 resid 109:115"""))

    AtomSel("known").apply(fitter)

    # place fitted structure in list
    global atomPosList
    atomPosList.append( sim.atomPosArr() )
    
#
#  load and fit specified structures
#
objs = vmd.loadFiles(structRange=[1,10,11,12,13,14,15,16,17,18,19],
                     filename="cterm_STRUCTURE.fit",
                     command=fitCmd,
                     displaySel="""(name ca or name c or name n)
                     and resid 109:115"""
                     )

for obj in objs:
    obj.color("red")
    pass

from atomProb import AtomProb
from atomSel import AtomSel

# make certain that VMD is in same directory as Xplor-NIH
cwd = os.getcwd()
vmd.tclCommand("cd " + cwd)

#
# make an AtomProb object with structures in atomPosList. The prob. map
# is made up of those atoms listed in the selection string
#
map = AtomProb( AtomSel("(name ca or name c or name n) and resid 109:112") ,
                atomPosList )

#
# to set grid values by hand
#
#map.gridVals.xmin=-2
#map.gridVals.xmax=2
#map.gridVals.xdelta=0.5
#map.gridVals.ydelta=0.5
#map.gridVals.zdelta=0.5
#map.gridVals.cushion=2

#
# other tweaking:
map.setScaleType("flat")
#map.setFullMap(1)
#map.setDistType("gaussian")
#map.setAtomRadius(1.2)

print "verbose: " , map.verbose()

map.setVerbose(1)

print "verbose: " , map.verbose()
#
# do the work and write out an edm file
#
map.calc()

edmFile = "flat.edm"
map.writeEDM(edmFile)

#load this into VMD
vmd.tclCommand("set probWid_edmFilename " + edmFile)
vmd.tclCommand("set probWid_edmMode file")
vmd.tclCommand("probWid_load -lines -threshold 40")
time.sleep(2) # let vmd get started
vmd.tclCommand('while {$probWid_status != "idle"} { vwait probWid_status }')
#
#

#
# This is a reweighted density map
#
map.setScaleType("amplitude")
map.calc()

edmFile = "amplitude.edm"
map.writeEDM(edmFile)

#load this into VMD
time.sleep(2) # let vmd get started
vmd.tclCommand('while {$probWid_status != "idle"} { vwait probWid_status }')
vmd.tclCommand("set probWid_edmFilename " + edmFile)
vmd.tclCommand("set probWid_edmMode file")
vmd.tclCommand("probWid_load -lines -threshold 40")
time.sleep(2) # let vmd get started

time.sleep(2) # let vmd get started
vmd.tclCommand('while {$probWid_status != "idle"} { vwait probWid_status }')
