
from xplor import command
from vmdInter import VMDInter
from atomSel import AtomSel

#load a pdb file containing docked proteins EI, and HPr
import protocol
protocol.loadPDB('dock.pdb',
                 deleteUnknownAtoms=True)

vmd = VMDInter()

#make a VMD object for EI
e1 = vmd.makeObj("e1")
e1.bonds("(name ca or name c or name n) and resid 1:259","NewCartoon")
e1.color("yellow")

#make a VMD object for HPr - in Cartoon representation
hpr = vmd.makeObj("hpr")
hpr.bonds(AtomSel("(name ca or name c or name n) and resid 300:385"),
          "Newcartoon")
hpr.color("green")

#load and test distance restraints
vmd.tclCommand("noeWid_create")
vmd.tclCommand("""set n e1
               foreach m [molinfo list] {
                 if {$n==[molinfo $m get name]} {
                   noeWid_molSet mol1 $m $n
                 }
               }""")
vmd.tclCommand("""set n hpr
               foreach m [molinfo list] {
                 if {$n==[molinfo $m get name]} {
                   noeWid_molSet mol2 $m $n
                 }
               }""")
vmd.tclCommand("set noeWid_noeFilename noe.in;return {}")
vmd.tclCommand(".noeWid.noeFilename.load invoke")

print "testing total number of NOEs...",
vmd.tclCommand("""if { [lindex [split [noe info]] 3] != 117 } {
                 return FAILED
               } else {
                 return ok
               }""")

print "testing noe rms...",
vmd.tclCommand("""if { [expr abs([noe calc]-0.848528)]>0.00001 } {
                 return FAILED
               } else {
                 return ok
               }""")
