
from vmdInter import VMDInter
from atomSel import AtomSel
from xplor import command

import protocol

#load pdb, generate psf info
protocol.loadPDB("gb1_xray1.pdb",deleteUnknownAtoms=True)

vmd = VMDInter()

#!******************
#!display backbone atoms
#!*****************
x = vmd.makeObj("x")
x.bonds( AtomSel("name ca or name c or name n") )

#!******************
#!display nonhydrogen sidechain atoms excluding isoleucine
#!*****************
xs = vmd.makeObj("xs")
xs.bonds( AtomSel("""not hydro and not (name c or name n or name o)
                        and not resname ile""") )

#!******************
#!create a second Simulation to contain an additional coordinate set
#!*****************
import xplorSimulation
xsim = xplorSimulation.XplorSimulation()

#!******************
#!read in a second set of coordinates with a possibly differing PSF
#!*****************
protocol.loadPDB("g_trio_tmv_bice_rgyrx_ave.chr",deleteUnknownAtoms=True,
                 simulation=xsim)

#!******************
#!fit these coordinates to previous set
#! including only alpha carbons of residues 1 to 56
#!*****************
from atomSelAction import Fit
AtomSel("all",xsim).apply( Fit( AtomSel("name CA"), AtomSel("name CA",xsim) ))

#!******************
#!display backbone atoms of fitted coordinates
#!*****************
s1 = vmd.makeObj("1")
s1.bonds( AtomSel("name ca or name c or name n", xsim) )

#!******************
#!draw labels for each alpha carbon
#!*****************
label = vmd.makeObj("label")
label.labelSize=2
label.labelResid=1
label.labelResname=0
label.labelAtomName=0
label.labels( AtomSel("name ca",xsim) )
