
#load coordinates and generate PSF
import protocol
protocol.loadPDB('hpr_iia.pdb',deleteUnknownAtoms=True)

#delete unwanted iia domain
xplor.simulation.deleteAtoms('resid 1:299')

#load rdc table into a potential term
from rdcPotTools import create_RDCPot
rdcs=create_RDCPot('rdcs','hpr_dipo.tbl')
rdcs.setScale(30)

#set the alignment tensor using the observed RDCs and the loaded
# structure via SVD
from varTensorTools import calcTensor
calcTensor(rdcs.oTensor)

#initialize torsion angle database
protocol.initRamaDatabase()

#generate a potential surface on which to do dynamics
from potList import PotList
potList = PotList()

potList.append(rdcs)

# add nonexperimental terms
from xplorPot import XplorPot
for term in ('BOND','ANGL','IMPR','RAMA'):
    potList.append( XplorPot(term) )
    pass

#create object to communicate with VMD
from vmdInter import VMDInter
vmd=VMDInter()

# create object which draws bonds during minimization
minObj=vmd.makeObj("minimization")
minObj.bonds("not PSEUDO and not name H*")

# create IVM object for dynamics
from ivm import IVM
ivm=IVM()

#create trajectory object and specify that the IVM will write to it
from vmdInter import VMDTraj
ivm.setTrajectory( VMDTraj(minObj,
                           saveInterval=10) ) # write frame every 10 steps


# configure large uniform masses
protocol.massSetup()

# activate only torsion-angle degrees of freedom
protocol.torsionTopology(ivm)

#initial quenching minimization
protocol.initMinimize(ivm,
                      potList=potList,
                      numSteps=500)
ivm.run()

# create object which draws bonds during dynamics
dynObj=vmd.makeObj("dynamics")
dynObj.bonds("not PSEUDO and not name H*")

ivm.setTrajectory( VMDTraj(dynObj,
                           saveInterval=10) ) # write frame every 10 steps


#setup for molecular dynamics
protocol.initDynamics(ivm,
                      initVelocities=True,
                      potList=potList,
                      bathTemp=1000,
                      finalTime=10)

ivm.run()
